---
title: <span class="badge object-type-scalar"></span> MicrosievertPerHour
---
# <span class="badge object-type-scalar"></span> MicrosievertPerHour

Radiation: microSievert/hour (µSv/h)

## Definition

```python
# Radiation: microSievert/hour (µSv/h)
MicrosievertPerHour: typing.Literal["radusvh"] = "radusvh"
```
